caugi (internal)Internal function to create the state environment for a
caugi. This function is not intended to be used directly by users.
.cg_state(nodes, edges, ptr, built, simple, class, name_index_map)An environment containing the graph state.
A data.table of nodes with a name column.
A data.table of edges with from, edge, and to columns.
A pointer to the underlying Rust graph structure
(or NULL if not built).
Logical; whether the graph has been built.
Logical; whether the graph is simple (no parallel edges or self-loops).
Character; one of "UNKNOWN", "DAG", "UG", "PDAG", "ADMG", or "AG".
A fastmap mapping node names to their zero indexed
indices.