Learn R Programming

caugi (version 1.0.0)

.contains_edge: Does the expression contain an edge call?

Description

Recursively check if the expression contains any edge call.

Usage

.contains_edge(expr)

Value

TRUE if the expression contains an edge call, FALSE otherwise

Arguments

expr

An expression to check