Learn R Programming

caugi (version 1.1.0)

.edge_units_to_dt: Turn edge units into a data.table of edges

Description

Convert a list of edge units into a data.table with columns from, edge, and to.

Usage

.edge_units_to_dt(units)

Value

A data.table with columns from, edge, and to.

Arguments

units

A list of edge units, each with lhs, rhs, and glyph.