Learn R Programming

caugi (version 1.0.0)

.is_edge_call: Is it an edge call / expression?

Description

This function checks if the expression is an edge call

Usage

.is_edge_call(expr)

Value

TRUE if the expression is an edge call, FALSE otherwise

Arguments

expr

An expression to check