Learn R Programming

caugi (version 1.0.0)

.mark_not_built: Mark a caugi as not built.

Description

When a caugi is modified, it should be marked as not built. This function sets the built attribute to FALSE. Thereby, the Rust backend and the R frontend does not match, and at one point, the caugi will need to be rebuild for it to be queried.

Usage

.mark_not_built(cg)

Value

The same caugi object, but with the built attribute set to FALSE.

Arguments

cg

A caugi object.