Learn R Programming

caugi (version 1.0.0)

.not_m_separated_for_all_subsets: Check if nodes are NOT m-separated for all conditioning subsets

Description

Tests whether two nodes fail to be m-separated for every possible conditioning set formed from other_nodes combined with cond_vars. If they are never separated, they must be adjacent in the resulting graph.

Usage

.not_m_separated_for_all_subsets(cg, node_a, node_b, other_nodes, cond_vars)

Value

TRUE if nodes are not m-separated for any subset (i.e., adjacent).

Arguments

cg

A caugi object.

node_a

First node name.

node_b

Second node name.

other_nodes

Other remaining nodes to form conditioning sets from.

cond_vars

Conditioning variables (always included in conditioning).