Learn R Programming

caugi (version 1.0.0)

.set_names: Set names to an object

Description

Only made to avoid using stats::setNames.

Usage

.set_names(object = nm, nm)

Value

The input object with the assigned names.

Arguments

object

An R object to which names are to be assigned.

nm

A character vector of names to assign to the object.