Learn R Programming

caugi (version 1.1.0)

dag_from_pdag: Extend a PDAG to a DAG using the Dor-Tarsi Algorithm

Description

Given a Partially Directed Acyclic Graph (PDAG), this function attempts to extend it to a Directed Acyclic Graph (DAG) by orienting the undirected edges while preserving acyclicity and all existing directed edges. The procedure implements the Dor-Tarsi algorithm.

If the PDAG cannot be consistently extended to a DAG, the function will raise an error.

Usage

dag_from_pdag(PDAG)

Value

A caugi object of class "DAG" representing a DAG extension of the input PDAG.

Arguments

PDAG

A caugi object of class "PDAG".

References

Dor, D., & Tarsi, M. (1992). "A simple algorithm to construct a consistent extension of a partially directed acyclic graph".

See Also

Other operations: condition_marginalize(), exogenize(), latent_project(), meek_closure(), moralize(), mutate_caugi(), normalize_latent_structure(), skeleton()

Examples

Run this code
PDAG <- caugi(
  A %---% B,
  B %---% C,
  class = "PDAG"
)
DAG <- dag_from_pdag(PDAG)
edges(DAG)

Run the code above in your browser using DataLab