Learn R Programming

caugi (version 1.0.0)

is_edge_symmetric: Is the edge symmetric?

Description

Check if the given edge glyph is symmetric in the edge registry.

Usage

is_edge_symmetric(glyph)

Value

Logical, TRUE if the edge is symmetric, otherwise throws error.

Arguments

glyph

A string representing the edge glyph (e.g., "-->", "<->").