Learn R Programming

caugi (version 1.0.0)

mutate_caugi: Mutate caugi class

Description

Mutate the caugi class from one graph class to another, if possible. For example, convert a DAG to a PDAG, or a fully directed caugi of class UNKNOWN to a DAG. Throws an error if not possible.

Usage

mutate_caugi(cg, class)

Value

A caugi object of the specified class.

Arguments

cg

A caugi object.

class

A character string specifying the new class.

Details

This function returns a copy of the object, and the original remains unchanged.

See Also

Other operations: condition_marginalize(), exogenize(), latent_project(), moralize(), skeleton()

Examples

Run this code
cg <- caugi(A %-->% B, class = "UNKNOWN")
cg_dag <- mutate_caugi(cg, "DAG")

Run the code above in your browser using DataLab