Learn R Programming

caugi (version 1.1.0)

skeleton: Get the skeleton of a graph

Description

The skeleton of a graph is obtained by replacing all directed edges with undirected edges.

Usage

skeleton(cg)

Value

A caugi object representing the skeleton of the graph (UG).

Arguments

cg

A caugi object. Either a DAG or PDAG.

Details

This changes the graph from any class to an Undirected Graph (UG), also known as a Markov Graph.

See Also

Other operations: condition_marginalize(), dag_from_pdag(), exogenize(), latent_project(), meek_closure(), moralize(), mutate_caugi(), normalize_latent_structure()

Examples

Run this code
cg <- caugi(A %-->% B, class = "DAG")
skeleton(cg) # A --- B

Run the code above in your browser using DataLab