.caugi_fit_on_line: Fit items on a line
Description
Helper function to determine how many items can fit on a line
of given width, considering an indent.
Usage
.caugi_fit_on_line(items, width, indent)
Value
An integer indicating how many items fit on the line.
Arguments
- items
A character vector of item labels.
- width
An integer specifying the total line width.
- indent
An integer specifying the indent width.