powered by
data.table
Convert a list of edge units into a data.table with columns from, edge, and to.
from
edge
to
.edge_units_to_dt(units)
A data.table with columns from, edge, and to.
A list of edge units, each with lhs, rhs, and glyph.
lhs
rhs
glyph