powered by
Only made to avoid using stats::setNames.
stats::setNames
.set_names(object = nm, nm)
The input object with the assigned names.
An R object to which names are to be assigned.
A character vector of names to assign to the object.