caugiInternal helper to add or remove nodes/edges. Rust is the source of truth - we get current state from Rust, modify it, and build a new session.
.update_caugi(
cg,
nodes = NULL,
edges = NULL,
action = c("add", "remove", "replace"),
inplace = FALSE
)The updated caugi object.
A caugi object.
A data.frame with column name for node names to add/remove.
A data.frame with columns from, edge, to for edges to
add/remove.
One of "add", "remove", or "replace".
DEPRECATED Ignored. Kept for backward compatibility.