Learn R Programming

caugi (version 1.0.0)

.update_caugi: Update nodes and edges of a caugi

Description

Internal helper to add or remove nodes/edges and mark graph as not built.

Usage

.update_caugi(
  cg,
  nodes = NULL,
  edges = NULL,
  action = c("add", "remove"),
  inplace = FALSE
)

Value

The updated caugi object.

Arguments

cg

A caugi object.

nodes

A data.frame with column name for node names to add/remove.

edges

A data.frame with columns from, edge, to for edges to add/remove.

action

One of "add" or "remove".

inplace

Logical, whether to modify the graph inplace or not.