caugiInternal helper to add or remove nodes/edges and mark graph as not built.
.update_caugi(
cg,
nodes = NULL,
edges = NULL,
action = c("add", "remove"),
inplace = FALSE
)The updated caugi object.
A caugi object.
A data.frame with column name for node names to add/remove.
A data.frame with columns from, edge, to for edges to
add/remove.
One of "add" or "remove".
Logical, whether to modify the graph inplace or not.