powered by
Check if the given edge glyph is symmetric in the edge registry.
is_edge_symmetric(glyph)
Logical, TRUE if the edge is symmetric, otherwise throws error.
TRUE
A string representing the edge glyph (e.g., "-->", "<->").
"-->"
"<->"